@@ -1,8 +1,5 @@
 package Clang;
-{
-  $Clang::VERSION = '0.06';
-}
-
+$Clang::VERSION = '0.07';
 use strict;
 use warnings;
 
@@ -15,12 +12,10 @@ Clang - Perl bindings to the Clang compiler's indexing interface
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
-    use v5.10;
-
     use Clang;
 
     my $index = Clang::Index -> new(1);
